@@ -24,7 +24,7 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
 import math
 from copy import deepcopy
 # mine
-import hwrt.HandwrittenData as HandwrittenData
+import HandwrittenData as HandwrittenData
 
 
 def get_class(name):
