@@ -28,8 +28,8 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
 from shapely.geometry import LineString
 import itertools
 # mine
-import hwrt.HandwrittenData as HandwrittenData
-import hwrt.preprocessing as preprocessing
+import HandwrittenData as HandwrittenData
+import preprocessing
 
 
 def get_class(name):
