@@ -25,7 +25,7 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
 # mine
-import hwrt.HandwrittenData as HandwrittenData
+import HandwrittenData as HandwrittenData
 
 
 def _euclidean_distance(p1, p2):
